==> elgg-2.3.5.zip: elgg-2.3.5/mod/file/languages/fi.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'file' => "Tiedostot",
	'file:user' => "Käyttäjän %s tiedostot",
	'file:friends' => "Ystävien tiedostot",
	'file:all' => "Kaikki sivuston tiedostot",
	'file:edit' => "Muokkaa tiedostoa",
	'file:more' => "Lisää tiedostoja",
	'file:list' => "listanäkymä",
	'file:group' => "Ryhmän tiedostot",
	'file:gallery' => "gallerianäkymä",
	'file:gallery_list' => "Galleria- tai listanäkymä",
	'file:num_files' => "Näytettävien kohteiden määrä",
	'file:user:gallery'=>'Näytä käyttäjän %s galleria',
	'file:upload' => "Lisää uusi tiedosto",
	'file:replace' => 'Korvaa tiedoston sisältö (jätä tyhjäksi säilyttääksesi nykyisen tiedoston)',
	'file:list:title' => "%s's %s %s",
	'file:title:friends' => "Ystävät",

	'file:add' => 'Lisää uusi tiedosto',

	'file:file' => "Tiedosto",

	'file:list:list' => 'Vaihta listanäkymään',
	'file:list:gallery' => 'Vaihda gallerianäkymään',

	'file:types' => "Lisätyt tiedostotyypit",

	'file:type:' => 'Tiedostot',
	'file:type:all' => "Kaikki tiedostot",
	'file:type:video' => "Videot",
	'file:type:document' => "Dokumentit",
	'file:type:audio' => "Äänitiedostot",
	'file:type:image' => "Kuvat",
	'file:type:general' => "Muut tiedostot",

	'file:user:type:video' => "käyttäjän %s videot",
	'file:user:type:document' => "käyttäjän %s dokumentit",
	'file:user:type:audio' => "käyttäjän %s äänitiedostot",
	'file:user:type:image' => "käyttäjän %s kuvat",
	'file:user:type:general' => "käyttäjän %s muut tiedostot",

	'file:friends:type:video' => "Ystäviesi videot",
	'file:friends:type:document' => "Ystäviesi dokumentit",
	'file:friends:type:audio' => "Ystäviesi äänitiedostot",
	'file:friends:type:image' => "Ystäviesi kuvat",
	'file:friends:type:general' => "Ystäviesi muut tiedostot",

	'file:widget' => "Tiedostovimpain",
	'file:widget:description' => "Näytä viimeisimmät tiedostosi",

	'groups:enablefiles' => 'Ota käyttöön ryhmän tiedostot',

	'file:delete:confirm' => "Haluatko varmasti poistaa tämän tiedoston?",

	'file:upload_limit' => 'Suurin sallittu tiedostokoko: %s',

	'file:tagcloud' => "Tagipilvi",

	'file:display:number' => "Näytettävien kohteiden määrä",

	'river:create:object:file' => '%s lisäsin tiedoston %s',
	'river:comment:object:file' => '%s kommentoi tiedostoa %s',

	'item:object:file' => 'Tiedostot',

	'file:notify:summary' => 'Uusi tiedosto: %s',
	'file:notify:subject' => 'Uusi tiedosto %s',
	'file:notify:body' =>
'%s lisäsi uuden tiedoston: %s

%s

Voit nähdä tiedoston täällä:
%s
',

	/**
	 * Status messages
	 */

	'file:saved' => "Tiedosto tallennettu.",
	'file:deleted' => "Tiedosto poistettu.",

	/**
	 * Error messages
	 */

	'file:none' => "Ei tiedostoja.",
	'file:uploadfailed' => "Tiedoston tallentaminen epäonnistui.",
	'file:downloadfailed' => "Tiedoston lataaminen epäonnistui.",
	'file:deletefailed' => "Tiedoston poistaminen epäonnistui.",
	'file:noaccess' => "Sinulla ei ole oikeuksia tämän tiedoston muuttamiseen",
	'file:cannotload' => "There was an error uploading the file",
	'file:nofile' => "Sinun pitää valita tiedosto",
);

==> elgg-2.3.9.zip: elgg-2.3.9/mod/file/languages/fi.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'file' => "Tiedostot",
	'file:user' => "Käyttäjän %s tiedostot",
	'file:friends' => "Ystävien tiedostot",
	'file:all' => "Kaikki sivuston tiedostot",
	'file:edit' => "Muokkaa tiedostoa",
	'file:more' => "Lisää tiedostoja",
	'file:list' => "listanäkymä",
	'file:group' => "Ryhmän tiedostot",
	'file:gallery' => "gallerianäkymä",
	'file:gallery_list' => "Galleria- tai listanäkymä",
	'file:num_files' => "Näytettävien kohteiden määrä",
	'file:user:gallery'=>'Näytä käyttäjän %s galleria',
	'file:upload' => "Lisää uusi tiedosto",
	'file:replace' => 'Korvaa tiedoston sisältö (jätä tyhjäksi säilyttääksesi nykyisen tiedoston)',
	'file:list:title' => "%s's %s %s",
	'file:title:friends' => "Ystävät",

	'file:add' => 'Lisää uusi tiedosto',

	'file:file' => "Tiedosto",

	'file:list:list' => 'Vaihta listanäkymään',
	'file:list:gallery' => 'Vaihda gallerianäkymään',

	'file:types' => "Lisätyt tiedostotyypit",

	'file:type:' => 'Tiedostot',
	'file:type:all' => "Kaikki tiedostot",
	'file:type:video' => "Videot",
	'file:type:document' => "Dokumentit",
	'file:type:audio' => "Äänitiedostot",
	'file:type:image' => "Kuvat",
	'file:type:general' => "Muut tiedostot",

	'file:user:type:video' => "käyttäjän %s videot",
	'file:user:type:document' => "käyttäjän %s dokumentit",
	'file:user:type:audio' => "käyttäjän %s äänitiedostot",
	'file:user:type:image' => "käyttäjän %s kuvat",
	'file:user:type:general' => "käyttäjän %s muut tiedostot",

	'file:friends:type:video' => "Ystäviesi videot",
	'file:friends:type:document' => "Ystäviesi dokumentit",
	'file:friends:type:audio' => "Ystäviesi äänitiedostot",
	'file:friends:type:image' => "Ystäviesi kuvat",
	'file:friends:type:general' => "Ystäviesi muut tiedostot",

	'file:widget' => "Tiedostovimpain",
	'file:widget:description' => "Näytä viimeisimmät tiedostosi",

	'groups:enablefiles' => 'Ota käyttöön ryhmän tiedostot',

	'file:delete:confirm' => "Haluatko varmasti poistaa tämän tiedoston?",

	'file:upload_limit' => 'Suurin sallittu tiedostokoko: %s',

	'file:tagcloud' => "Tagipilvi",

	'file:display:number' => "Näytettävien kohteiden määrä",

	'river:create:object:file' => '%s lisäsin tiedoston %s',
	'river:comment:object:file' => '%s kommentoi tiedostoa %s',

	'item:object:file' => 'Tiedostot',

	'file:notify:summary' => 'Uusi tiedosto: %s',
	'file:notify:subject' => 'Uusi tiedosto %s',
	'file:notify:body' =>
'%s lisäsi uuden tiedoston: %s

%s

Voit nähdä tiedoston täällä:
%s
',

	/**
	 * Status messages
	 */

	'file:saved' => "Tiedosto tallennettu.",
	'file:deleted' => "Tiedosto poistettu.",

	/**
	 * Error messages
	 */

	'file:none' => "Ei tiedostoja.",
	'file:uploadfailed' => "Tiedoston tallentaminen epäonnistui.",
	'file:downloadfailed' => "Tiedoston lataaminen epäonnistui.",
	'file:deletefailed' => "Tiedoston poistaminen epäonnistui.",
	'file:noaccess' => "Sinulla ei ole oikeuksia tämän tiedoston muuttamiseen",
	'file:cannotload' => "Tiedoston lataamisessa tapahtui virhe",
	'file:nofile' => "Sinun pitää valita tiedosto",
);
